# aws-list-subnets

command line tool to list AWS subnets.

## Installation

    $ pip install aws-list-subnets

## License

This project is licensed under the terms of the [MIT License](https://opensource.org/licenses/MIT).

